@@ -238,8 +238,8 @@ impl<'a> ImageHandler for Box<dyn ImageHandler> {
 pub fn image_handler_detect(
     term: &mut dyn Terminal,
 ) -> Result<Box<dyn ImageHandler + 'static>, Error> {
-    // NOTE: this function will not work on the second call, kitty handler will not propaget event
-    // drain terminal
+    // NOTE: will not work if kitty handler has already been set, as it would
+    // consume event generated by terminal inside `ImageHandler::handle`
     while term.poll(Some(Duration::new(0, 0)))?.is_some() {}
     // Send kitty query and DA1 request
     term.write_all(b"\x1b_Ga=q,i=31,s=1,v=1,f=24;AAAA\x1b\\")?; // kitty image
@@ -439,7 +439,7 @@ impl ImageHandler for KittyImageHandler {
             let payload = payload_write.finish()?.finish()?;
 
             // data needs to be transfered in chunks
-            let chunks = payload.chunks(4096);
+            let chunks = payload.chunks(4095);
             let count = chunks.len();
             for (index, chunk) in chunks.enumerate() {
                 // control data
@@ -510,6 +510,7 @@ impl ImageHandler for KittyImageHandler {
         match event {
             TerminalEvent::KittyImage { id, error } => {
                 let filter = if !error.is_none() {
+                    tracing::warn!("kitty image error: {:?}", error);
                     // remove elemnt from cache, and propagate event to
                     // the user which will cause the redraw
                     self.imgs.remove(id);
